==> kubernetes-model-networking-5.7.3-sources.jar: io/fabric8/kubernetes/api/model/networking/v1/IPBlockFluentImpl.java <==
package io.fabric8.kubernetes.api.model.networking.v1;

import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public class IPBlockFluentImpl<A extends io.fabric8.kubernetes.api.model.networking.v1.IPBlockFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.kubernetes.api.model.networking.v1.IPBlockFluent<A>{
  public IPBlockFluentImpl() {
  }
  public IPBlockFluentImpl(io.fabric8.kubernetes.api.model.networking.v1.IPBlock instance) {
    this.withCidr(instance.getCidr()); 
    this.withExcept(instance.getExcept()); 
  }
  private java.lang.String cidr;
  private java.util.List<java.lang.String> except = new java.util.ArrayList<java.lang.String>();
  public java.lang.String getCidr() {
    return this.cidr;
  }
  public A withCidr(java.lang.String cidr) {
    this.cidr=cidr; return (A) this;
  }
  public java.lang.Boolean hasCidr() {
    return this.cidr != null;
  }
  
  /**
   * Method is deprecated. use withCidr instead.
   */
  @java.lang.Deprecated
  public A withNewCidr(java.lang.String arg0) {
    return (A)withCidr(new String(arg0));
  }
  public A addToExcept(java.lang.Integer index,java.lang.String item) {
    if (this.except == null) {this.except = new java.util.ArrayList<java.lang.String>();}
    this.except.add(index, item);
    return (A)this;
  }
  public A setToExcept(java.lang.Integer index,java.lang.String item) {
    if (this.except == null) {this.except = new java.util.ArrayList<java.lang.String>();}
    this.except.set(index, item); return (A)this;
  }
  public A addToExcept(java.lang.String... items) {
    if (this.except == null) {this.except = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.except.add(item);} return (A)this;
  }
  public A addAllToExcept(java.util.Collection<java.lang.String> items) {
    if (this.except == null) {this.except = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.except.add(item);} return (A)this;
  }
  public A removeFromExcept(java.lang.String... items) {
    for (java.lang.String item : items) {if (this.except!= null){ this.except.remove(item);}} return (A)this;
  }
  public A removeAllFromExcept(java.util.Collection<java.lang.String> items) {
    for (java.lang.String item : items) {if (this.except!= null){ this.except.remove(item);}} return (A)this;
  }
  public java.util.List<java.lang.String> getExcept() {
    return this.except;
  }
  public java.lang.String getExcept(java.lang.Integer index) {
    return this.except.get(index);
  }
  public java.lang.String getFirstExcept() {
    return this.except.get(0);
  }
  public java.lang.String getLastExcept() {
    return this.except.get(except.size() - 1);
  }
  public java.lang.String getMatchingExcept(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: except) { if(predicate.test(item)){ return item;} } return null;
  }
  public java.lang.Boolean hasMatchingExcept(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: except) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withExcept(java.util.List<java.lang.String> except) {
    if (except != null) {this.except = new java.util.ArrayList<java.lang.String>(); for (java.lang.String item : except){this.addToExcept(item);}} else { this.except = null;} return (A) this;
  }
  public A withExcept(java.lang.String... except) {
    if (this.except != null) {this.except.clear();}
    if (except != null) {for (java.lang.String item :except){ this.addToExcept(item);}} return (A) this;
  }
  public java.lang.Boolean hasExcept() {
    return except != null && !except.isEmpty();
  }
  public A addNewExcept(java.lang.String arg0) {
    return (A)addToExcept(new String(arg0));
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    IPBlockFluentImpl that = (IPBlockFluentImpl) o;
    if (cidr != null ? !cidr.equals(that.cidr) :that.cidr != null) return false;
    if (except != null ? !except.equals(that.except) :that.except != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(cidr,  except,  super.hashCode());
  }
  
}

==> kubernetes-model-networking-5.11.1-sources.jar: io/fabric8/kubernetes/api/model/networking/v1/IPBlockFluentImpl.java <==
package io.fabric8.kubernetes.api.model.networking.v1;

import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class IPBlockFluentImpl<A extends io.fabric8.kubernetes.api.model.networking.v1.IPBlockFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.kubernetes.api.model.networking.v1.IPBlockFluent<A>{
  public IPBlockFluentImpl() {
  }
  public IPBlockFluentImpl(io.fabric8.kubernetes.api.model.networking.v1.IPBlock instance) {
    this.withCidr(instance.getCidr()); 
    this.withExcept(instance.getExcept()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String cidr;
  private java.util.List<java.lang.String> except = new java.util.ArrayList<java.lang.String>();
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getCidr() {
    return this.cidr;
  }
  public A withCidr(java.lang.String cidr) {
    this.cidr=cidr; return (A) this;
  }
  public java.lang.Boolean hasCidr() {
    return this.cidr != null;
  }
  
  /**
   * Method is deprecated. use withCidr instead.
   */
  @java.lang.Deprecated
  public A withNewCidr(java.lang.String arg0) {
    return (A)withCidr(new String(arg0));
  }
  public A addToExcept(java.lang.Integer index,java.lang.String item) {
    if (this.except == null) {this.except = new java.util.ArrayList<java.lang.String>();}
    this.except.add(index, item);
    return (A)this;
  }
  public A setToExcept(java.lang.Integer index,java.lang.String item) {
    if (this.except == null) {this.except = new java.util.ArrayList<java.lang.String>();}
    this.except.set(index, item); return (A)this;
  }
  public A addToExcept(java.lang.String... items) {
    if (this.except == null) {this.except = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.except.add(item);} return (A)this;
  }
  public A addAllToExcept(java.util.Collection<java.lang.String> items) {
    if (this.except == null) {this.except = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.except.add(item);} return (A)this;
  }
  public A removeFromExcept(java.lang.String... items) {
    for (java.lang.String item : items) {if (this.except!= null){ this.except.remove(item);}} return (A)this;
  }
  public A removeAllFromExcept(java.util.Collection<java.lang.String> items) {
    for (java.lang.String item : items) {if (this.except!= null){ this.except.remove(item);}} return (A)this;
  }
  public java.util.List<java.lang.String> getExcept() {
    return this.except;
  }
  public java.lang.String getExcept(java.lang.Integer index) {
    return this.except.get(index);
  }
  public java.lang.String getFirstExcept() {
    return this.except.get(0);
  }
  public java.lang.String getLastExcept() {
    return this.except.get(except.size() - 1);
  }
  public java.lang.String getMatchingExcept(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: except) { if(predicate.test(item)){ return item;} } return null;
  }
  public java.lang.Boolean hasMatchingExcept(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: except) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withExcept(java.util.List<java.lang.String> except) {
    if (except != null) {this.except = new java.util.ArrayList<java.lang.String>(); for (java.lang.String item : except){this.addToExcept(item);}} else { this.except = null;} return (A) this;
  }
  public A withExcept(java.lang.String... except) {
    if (this.except != null) {this.except.clear();}
    if (except != null) {for (java.lang.String item :except){ this.addToExcept(item);}} return (A) this;
  }
  public java.lang.Boolean hasExcept() {
    return except != null && !except.isEmpty();
  }
  public A addNewExcept(java.lang.String arg0) {
    return (A)addToExcept(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    IPBlockFluentImpl that = (IPBlockFluentImpl) o;
    if (cidr != null ? !cidr.equals(that.cidr) :that.cidr != null) return false;
    if (except != null ? !except.equals(that.except) :that.except != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(cidr,  except,  additionalProperties,  super.hashCode());
  }
  
}
